@@ -4,7 +4,7 @@
 modname = 'comment'
 distname = "cubicweb-%s" % modname
 
-numversion = (1, 12, 1)
+numversion = (1, 12, 2)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -13,10 +13,10 @@ author_email = "contact@logilab.fr"
 web = 'http://www.cubicweb.org/project/%s' % distname
 description = "commenting system for the CubicWeb framework"
 classifiers = [
-           'Environment :: Web Environment',
-           'Framework :: CubicWeb',
-           'Programming Language :: Python',
-           'Programming Language :: JavaScript',
+    'Environment :: Web Environment',
+    'Framework :: CubicWeb',
+    'Programming Language :: Python',
+    'Programming Language :: JavaScript',
 ]
 
 __depends__ = {'cubicweb': '>= 3.19.0'}
@@ -30,18 +30,21 @@ from glob import glob
 
 THIS_CUBE_DIR = join('share', 'cubicweb', 'cubes', modname)
 
+
 def listdir(dirpath):
     return [join(dirpath, fname) for fname in _listdir(dirpath)
             if fname[0] != '.' and not fname.endswith('.pyc')
             and not fname.endswith('~')
             and not isdir(join(dirpath, fname))]
 
+
 data_files = [
     # common files
     [THIS_CUBE_DIR, [fname for fname in glob('*.py') if fname != 'setup.py']],
     ]
 # check for possible extended cube layout
-for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18n', 'migration', 'wdoc'):
+for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data',
+                'i18n', 'migration', 'wdoc'):
     if isdir(dirname):
         data_files.append([join(THIS_CUBE_DIR, dirname), listdir(dirname)])
 # Note: here, you'll need to add subdirectories if you want
